import { ValidationError } from "./validation/ValidationError";
import { ValidatorOptions } from "./validation/ValidatorOptions";
import { ValidationSchema } from "./validation-schema/ValidationSchema";
import { ValidationArguments } from "./validation/ValidationArguments";
/**
 * Container options.
 */
export interface UseContainerOptions {
    /**
     * If set to true, then default container will be used in the case if given container haven't returned anything.
     */
    fallback?: boolean;
    /**
     * If set to true, then default container will be used in the case if given container thrown an exception.
     */
    fallbackOnErrors?: boolean;
}
/**
 * Sets container to be used by this library.
 */
export declare function useContainer(iocContainer: {
    get(someClass: any): any;
}, options?: UseContainerOptions): void;
/**
 * Gets the IOC container used by this library.
 */
export declare function getFromContainer<T>(someClass: {
    new (...args: any[]): T;
} | Function): T;
export * from "./decorator/decorators";
export * from "./decorator/ValidationOptions";
export * from "./validation/ValidatorConstraintInterface";
export * from "./validation/ValidationError";
export * from "./validation/ValidationTypeOptions";
export * from "./validation/ValidatorOptions";
export * from "./validation/ValidationArguments";
export * from "./validation/ValidationTypes";
export * from "./validation/Validator";
export * from "./validation-schema/ValidationSchema";
/**
 * Validates given object.
 */
export declare function validate(object: Object, validatorOptions?: ValidatorOptions): Promise<ValidationError[]>;
/**
 * Validates given object by a given validation schema.
 */
export declare function validate(schemaName: string, object: Object, validatorOptions?: ValidatorOptions): Promise<ValidationError[]>;
/**
 * Registers a new validation schema.
 */
export declare function registerSchema(schema: ValidationSchema): void;
/**
 * Registers a custom validation decorator.
 */
export declare function registerDecorator(object: Object, propertyName: string, validationOptions: ValidatorOptions, constraints: any[], constraintCls: Function): void;
/**
 * Registers a custom validation decorator.
 */
export declare function registerDecorator(object: Object, propertyName: string, validationOptions: ValidatorOptions, constraints: any[], validationName: string, validateCallback: (value?: any, args?: ValidationArguments) => boolean | Promise<boolean>, defaultMessageCallback?: (args?: ValidationArguments) => string): void;
